#!/bin/sh

echo "Doing clang-tidy..."
bool=false
# explicitly set IFS to contain only a line feed
IFS='
'
filelist="$(find . -not \( -path './*build*' -prune \) -type f ! -name "$(printf "*\n*")")"
for file in $filelist; do
  if echo "$file" | grep -q -E ".*(\.cpp|\.h|\.hpp)$" ; then
    #Extra check missing dependencies due to clang-tidy doesn't toggle exit code.
    clang_tidy_lib_check="$(clang-tidy -warnings-as-errors='*' -header-filter='.*,-cpptoml.hpp' -checks='*,-llvm-header-guard,-fuchsia-statically-constructed-objects,-fuchsia-default-arguments,-fuchsia-default-arguments-calls,-cppcoreguidelines-pro-bounds-pointer-arithmetic,-cppcoreguidelines-pro-bounds-constant-array-index,-bugprone-narrowing-conversions,-cppcoreguidelines-narrowing-conversions,-cppcoreguidelines-pro-type-const-cast,-cppcoreguidelines-pro-type-reinterpret-cast,-hicpp-signed-bitwise,-bugprone-exception-escape,-cppcoreguidelines-pro-type-member-init,-cppcoreguidelines-pro-type-cstyle-cast,-hicpp-member-init' "$file" -- -I. -std=c++14 2>&1)"
    for tidy_line in $clang_tidy_lib_check; do
      echo "$tidy_line" | grep -q -v -E "^Error while processing*"
      if [ $? -eq 1 ]; then
	bool=true
      fi
      echo "$tidy_line" | grep -q -v -E ".* error: .*"
      if [ $? -eq 1 ]; then
	bool=true
      fi
      echo "$tidy_line"
    done
  fi
done
if $bool; then
  exit 1
else
  echo "No clang-tidy errors found."
fi

exit 0
